@@ -9,6 +9,12 @@ TYPE = u"type"
 TITLE = u"title"
 NAME = u"name"
 ID_STRING = u"id_string"
+SMS_KEYWORD = u"sms_keyword"
+SMS_ID = u"sms_id"
+SMS_SEPARATOR = u"sms_separator"
+SMS_ALLOW_MEDIAS = u"sms_allow_medias"
+SMS_DATE_FORMAT = u"sms_date_format"
+SMS_DATETIME_FORMAT = u"sms_datetime_format"
 VERSION = u"version"
 PUBLIC_KEY = u"public_key"
 SUBMISSION_URL = u"submission_url"
