@@ -44,6 +44,11 @@ settings_header_aliases = {
     u"form_title": constants.TITLE,
     u"set form title": constants.TITLE,
     u"form_id": constants.ID_STRING,
+    u"sms_keyword": constants.SMS_KEYWORD,
+    u"sms_separator": constants.SMS_SEPARATOR,
+    u"sms_allow_medias": constants.SMS_ALLOW_MEDIAS,
+    u"sms_date_format": constants.SMS_DATE_FORMAT,
+    u"sms_datetime_format": constants.SMS_DATETIME_FORMAT,
     u"set form id": constants.ID_STRING,
     u"public_key": constants.PUBLIC_KEY,
     u"submission_url": constants.SUBMISSION_URL
@@ -53,6 +58,11 @@ settings_header_aliases = {
 survey_header_aliases = {
     u"Label": u"label",
     u"Name": u"name",
+    u"SMS ID": constants.SMS_ID,
+    u"SMS Sepatator": constants.SMS_SEPARATOR,
+    u"SMS Allow Medias": constants.SMS_ALLOW_MEDIAS,
+    u"SMS Date Format": constants.SMS_DATE_FORMAT,
+    u"SMS DateTime Format": constants.SMS_DATETIME_FORMAT,
     u"Type": u"type",
     u"List_name": u"list_name",
     u"repeat_count": u"jr:count",
@@ -401,11 +411,13 @@ def workbook_to_json(
 
     #Here we create our json dict root with default settings:
     id_string = settings.get(constants.ID_STRING, form_name)
+    sms_keyword = settings.get(constants.SMS_KEYWORD, id_string)
     json_dict = {
         constants.TYPE: constants.SURVEY,
         constants.NAME: form_name,
         constants.TITLE: id_string,
         constants.ID_STRING: id_string,
+        constants.SMS_KEYWORD: sms_keyword,
         constants.DEFAULT_LANGUAGE: default_language,
         #By default the version is based on the date and time yyyymmddhh
         #Leaving default version out for now since it might cause
